==> appinio_video_player-1.0.0.tar.gz: lib/src/controls/fullscreen_button.dart <==
import 'package:appinio_video_player/src/video_values_provider.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:video_player/video_player.dart';

class CustomVideoPlayerFullscreenButton extends StatelessWidget {
  final VideoPlayerController? videoPlayerController;
  final bool? isFullscreen;
  final VoidCallback? onStart;
  final VoidCallback? onPlayPause;
  final VoidCallback? onEnd;
  const CustomVideoPlayerFullscreenButton({
    Key? key,
    this.videoPlayerController,
    this.isFullscreen,
    this.onStart,
    this.onPlayPause,
    this.onEnd,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    VideoValuesProvider videoValuesProvider =
        Provider.of<VideoValuesProvider>(context, listen: false);
    return GestureDetector(
      behavior: HitTestBehavior.translucent,
      onTap: () {
        if (videoValuesProvider.customVideoPlayerController.isFullscreen) {
          videoValuesProvider.customVideoPlayerController.setFullscreen(false);
        } else {
          videoValuesProvider.customVideoPlayerController.setFullscreen(true);
        }
      },
      child: Provider.of<VideoValuesProvider>(context)
              .customVideoPlayerController
              .isFullscreen
          ? videoValuesProvider.customVideoPlayerSettings.exitFullscreenButton
          : videoValuesProvider.customVideoPlayerSettings.enterFullscreenButton,
    );
  }
}

class CustomVideoPlayerEnterFullscreenButton extends StatelessWidget {
  const CustomVideoPlayerEnterFullscreenButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.fromLTRB(0, 5, 5, 5),
      child: Icon(
        CupertinoIcons.fullscreen,
        color: CupertinoColors.white,
      ),
    );
  }
}

class CustomVideoPlayerExitFullscreenButton extends StatelessWidget {
  const CustomVideoPlayerExitFullscreenButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.fromLTRB(0, 5, 5, 5),
      child: Icon(
        CupertinoIcons.fullscreen_exit,
        color: CupertinoColors.white,
      ),
    );
  }
}

==> appinio_video_player-1.0.2.tar.gz: lib/src/controls/fullscreen_button.dart <==
import 'package:flutter/cupertino.dart';

import 'package:appinio_video_player/appinio_video_player.dart';

class CustomVideoPlayerFullscreenButton extends StatelessWidget {
  final CustomVideoPlayerController customVideoPlayerController;
  final CustomVideoPlayerSettings customVideoPlayerSettings;
  final bool? isFullscreen;
  const CustomVideoPlayerFullscreenButton({
    Key? key,
    required this.customVideoPlayerController,
    required this.customVideoPlayerSettings,
    this.isFullscreen,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      behavior: HitTestBehavior.translucent,
      onTap: () {
        if (customVideoPlayerController.isFullscreen) {
          customVideoPlayerController.setFullscreen(false);
        } else {
          customVideoPlayerController.setFullscreen(true);
        }
      },
      child: customVideoPlayerController.isFullscreen
          ? customVideoPlayerSettings.exitFullscreenButton
          : customVideoPlayerSettings.enterFullscreenButton,
    );
  }
}

class CustomVideoPlayerEnterFullscreenButton extends StatelessWidget {
  const CustomVideoPlayerEnterFullscreenButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.fromLTRB(0, 5, 5, 5),
      child: Icon(
        CupertinoIcons.fullscreen,
        color: CupertinoColors.white,
      ),
    );
  }
}

class CustomVideoPlayerExitFullscreenButton extends StatelessWidget {
  const CustomVideoPlayerExitFullscreenButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.fromLTRB(0, 5, 5, 5),
      child: Icon(
        CupertinoIcons.fullscreen_exit,
        color: CupertinoColors.white,
      ),
    );
  }
}
